%% Generate SLF
clear all, close all, clc
load engineInputs;  % Matlab binary data container
load engineTargets;
out = engineTargets(2,:); % take only one output - Nitrous oxide emission
dataset=[engineInputs;out];
%% splitting the data in training and checking data
[trainData, chkData, testData] = dividerand(dataset, 60, 25, 15);
trainData = trainData';
chkData = chkData';

%% Generate initial FLS
radii = 0.7
opt = genfisOptions('SubtractiveClustering', 'ClusterInfluenceRange', radii)
slfIni = genfis(trainData(:,1:2),trainData(:,3), opt);
 

writefis(slfIni, 'slfIni');

%% Train slf
maxEpoch = 100;
cpEpoch = 20; % intermediate check point 
tic
[slfCp, errCp, stepsize, slfChk, errChkCp] = ...
    anfis(trainData,slfIni,cpEpoch,[],chkData);
[slfEnd, errEnd, stepsize, slfChk, errChkEnd] = ...
    anfis(trainData,slfCp,maxEpoch-cpEpoch,[],chkData);
toc
err = [errCp; errEnd];
errChk = [errChkCp; errChkEnd];
iter = 1:maxEpoch;
h = figure;
hPlot_err = plot(iter, err);
hold on
hPlot_errChk = plot(iter, errChk);
cursorMode = datacursormode(h);
hDatatip_err = cursorMode.createDatatip(hPlot_err);
hDatatip_errChk = cursorMode.createDatatip(hPlot_errChk);
pos_err = [iter(cpEpoch) err(cpEpoch) 0];
pos_Chkerr = [iter(cpEpoch) errChk(cpEpoch) 0];
set(hDatatip_err, 'Position', [iter(cpEpoch) err(cpEpoch) 0]);
set(hDatatip_errChk, 'Position', [iter(cpEpoch) errChk(cpEpoch) 0]);
updateDataCursors(cursorMode);

 xlabel('epoch');
 ylabel('rmse');
 legend('training error','checking error');
 
writefis(slfCp, 'slfCp');
writefis(slfEnd, 'slfEnd');
writefis(slfChk, 'slfChk');
save trainData, trainData;
save testData, testData;
save chkData, chkData;
