%% 
% engine_dataset Engine behavior dataset.
%  
%   Function fitting is the process of training a neural network on a
%   set of inputs in order to produce an associated set of target outputs.
%   Once the neural network has fit the data, it forms a generalization of
%   the input-output relationship and can be used to generate outputs for
%   inputs it was not trained on.
%   This dataset can be used to train a neural network to estimate an
%   engines torque and emissions from its fuel use and speed. 
%   LOAD engine_dataset.MAT loads these two variables:
%     engineInputs - a 2x1199 matrix defining two attributes of a
%     given engines activity under different conditions:
%       1. Fuel rate
%       2. Speed
%     engineTargets - a 2x1199 matrix of two attributes to be estimated
%     given the inputs:
%       1. Torque
%       2. Nitrous oxide emissions
 
clear all, close all, clc

load('engineInputs')
load('engineTargets')
size = numel(engineInputs(1,:));

subplot(411)
plot(engineInputs(1,:))
legend('input: Fuel rate')
ylim([min(engineInputs(1,:))-20 max(engineInputs(1,:))+10])

subplot(412)
plot(engineInputs(2,:))
legend('input: Speed')
ylim([min(engineInputs(2,:))-20 max(engineInputs(2,:))+100])

subplot(413)
plot(engineTargets(1,:),'m')
legend('output: Torque')
ylim([min(engineTargets(1,:))-200 max(engineTargets(1,:))+100])

subplot(414)
plot(engineTargets(2,:),'g')
ylim([min(engineTargets(2,:))-200 max(engineTargets(2,:))+100])
legend('output: Nitrous oxide emission')
xlabel('sample')